@@ -1,7 +1,7 @@
 """
    SDC subscription model module
 """
-from sqlalchemy import Column, Integer, ForeignKey, JSON
+from sqlalchemy import Column, Integer, ForeignKey, JSON, String
 from sqlalchemy.orm import relationship, deferred, query_expression
 from sdc_helpers.models.model import Model, models_namespace
 
@@ -18,6 +18,7 @@ class Subscription(Model):
     # by default lazy load properties to avoid large data stores from automatically being pulled
     # at query time - use .options(undefer('properties')) on query to override default behaviour
     properties = deferred(Column(JSON))
+    updated_by = Column(String(255))
     properties_node = query_expression()
 
     client = relationship(
