@@ -1,8 +1,10 @@
 """
    SDC Query helper module
 """
+import inspect
 import os
 import json
+from datetime import datetime
 import boto3
 from sqlalchemy import create_engine, and_, literal
 from sqlalchemy.orm import sessionmaker, undefer, Query
@@ -25,6 +27,8 @@ class QueryHelper:
 
     session = None
     redis_helper = None
+    mysql_date_format = '%Y-%m-%d %H:%M:%S'
+    query_helper_caller = None
 
     def __init__(self, **kwargs):
         """
@@ -33,6 +37,17 @@ class QueryHelper:
                 rds_config (dict) : config arguments for mysql connector
                 redis_config (dict) : config arguments for redis connector
         """
+        caller_locals = inspect.currentframe().f_back.f_locals
+        caller_module = caller_locals.get('__module__')
+        caller_class = caller_locals.get('__qualname__')
+        self.query_helper_caller = caller_module
+
+        if caller_class is not None:
+            self.query_helper_caller = '{caller_module}.{caller_class}'.format(
+                caller_module=caller_locals.get('__module__'),
+                caller_class=caller_locals.get('__qualname__')
+            )
+
         # get rds config
         rds_config = kwargs.get('rds_config', {})
         rds_host = rds_config.get('host', None)
@@ -368,4 +383,12 @@ class QueryHelper:
             # need to mark it as such to cause an update in the database
             flag_modified(model, 'properties')
 
+        model.updated_at = datetime.strftime(
+            datetime.now(),
+            self.mysql_date_format
+        )
+
+        if hasattr(model, 'updated_by') and self.query_helper_caller is not None:
+            model.updated_by = self.query_helper_caller
+
         self.session.commit()
